from fastapi import APIRouter, HTTPException, status
from helpers.contact_form_helpers import create_contact_form, validate_email
from schemas.contact_form import ContactFormCreate
from sqlalchemy.orm import Session
from fastapi import Depends
from database import get_db

router = APIRouter()

@router.post("/form", status_code=status.HTTP_201_CREATED, response_model=ContactFormCreate)
async def create_form(contact_form_data: ContactFormCreate, db: Session = Depends(get_db)):
    if not contact_form_data.name or not contact_form_data.message or not contact_form_data.email or not validate_email(contact_form_data.email):
        raise HTTPException(status_code=400, detail="One or more required fields are missing or invalid")

    new_contact_form = create_contact_form(db=db, contact_form_data=contact_form_data)
    return new_contact_form